==> nextcloud-app-tasks-0.9.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/el.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Εργασίες",
    "Due yesterday" : "Προθεσμία χθες",
    "Due today" : "Προθεσμία σήμερα",
    "Due tomorrow" : "Προθεσμία αύριο",
    "Due on" : "Προθεσμία στις",
    "Started yesterday" : "Άρχισε χθες",
    "Starts today" : "Αρχίζει σήμερα",
    "Starts tomorrow" : "Αρχίζει αύριο",
    "Started on" : "Άρχισε στις",
    "Starts on" : "Αρχίζει στις",
    "[Remind me yesterday at ]HH:mm" : "[Θύμισέ μου χθες στις ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Θύμισέ μου σήμερα στις ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Θύμισέ μου αύριο στις ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Θύμισέ μου στις ]MMM DD, YYYY,[ στις ]HH:mm",
    "Yesterday" : "Χθες",
    "Today" : "Σήμερα",
    "Tomorrow" : "Αύριο",
    "in %s" : "σε %s",
    "%s ago" : "%s πριν",
    "seconds" : "δευτερόλεπτα",
    "a minute" : "ένα λεπτό",
    "%d minutes" : "%d λεπτά",
    "an hour" : "μια ώρα",
    "%d hours" : "%d ώρες",
    "a day" : "μια ημέρα",
    "%d days" : "%d ημέρες",
    "a month" : "ένας μήνας",
    "%d months" : "%d μήνες",
    "a year" : "ένα έτος",
    "%d years" : "%d έτη",
    "week" : "εβδομάδα",
    "weeks" : "εβδομάδες",
    "day" : "ημέρα",
    "days" : "ημέρες",
    "hour" : "ώρα",
    "hours" : "ώρες",
    "minute" : "λεπτό",
    "minutes" : "λεπτά",
    "second" : "δευτερόλεπτο",
    "before beginning" : "πριν την έναρξη",
    "after beginning" : "μετά την έναρξη",
    "before end" : "πριν τη λήξη",
    "after end" : "μετά τη λήξη",
    "Comment" : "Σχόλιο",
    "Add a comment" : "Προσθήκη σχολίου",
    "This will delete the Calendar \"%s\" and all of its entries." : "Αυτό θα διαγράψει το Ημερολόγιο \"%s\" και όλες τις εγγραφές του.",
    "The name \"%s\" is already used." : "Το όνομα \"%s\" χρησιμοποιείται ήδη.",
    "An empty name is not allowed." : "Δεν επιτρέπεται κενό όνομα.",
    "Hidden" : "Κρυφό",
    "Visible" : "Ορατό",
    "Automatic" : "Αυτόματο",
    "Sunday" : "Κυριακή",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Add an important item in \"%s\"..." : "Προσθήκη ενός σημαντικού στοιχείου στο \"%s\"...",
    "Add an item due today in \"%s\"..." : "Προσθήκη ενός στοιχείου με σημερινή προθεσμία στο \"%s\"...",
    "Add an item in \"%s\"..." : "Προσθήκη ενός στοιχείου στο \"%s\"...",
    "Add a current item in \"%s\"..." : "Προσθήκη ενός τρέχοντος στοιχείου στο \"%s\"...",
    "Add a subtask to \"%s\"..." : "Προσθήκη υποέργου σε \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Ολοκληρωμένη Εργασία","%n Ολοκληρωμένες Εργασίες"],
    "Hours" : "Ώρες",
    "Minutes" : "Λεπτά",
    "Set due date" : "Ορισμός προθεσμίας",
    "%s %% completed" : "%s %% ολοκληρωμένες",
    "priority %s: " : "προτεραιότητα %s:",
    "high" : "υψηλή",
    "medium" : "μεσαία",
    "low" : "χαμηλή",
    "no priority assigned" : "δεν έχει οριστεί προτεραιότητα",
    "Remind me" : "Θύμισέ μου",
    "at the end" : "στο τέλος",
    "at the beginning" : "στην αρχή",
    "Set start date" : "Ορισμός ημερομηνίας έναρξης",
    "Important" : "Σημαντικό ",
    "Week" : "Εβδομάδα",
    "All" : "Όλες",
    "Current" : "Τρέχουσα",
    "Completed" : "Ολοκληρωμένες",
    "Delete" : "Διαγραφή",
    "Cancel" : "Άκυρο",
    "Edit" : "Επεξεργασία",
    "Link" : "Σύνδεσμος",
    "Download" : "Λήψη",
    "Save" : "Αποθήκευση",
    "Add List..." : "Προσθήκη Λίστας...",
    "New List" : "Νέα Λίστα",
    "Settings" : "Ρυθμίσεις",
    "Start of week" : "Αρχή της εβδομάδας",
    "Visibility of Smart Collections" : "Ορατότητα Έξυπνων Συλλογών",
    "Default" : "Προκαθορισμένο",
    "Load remaining completed tasks." : "Φόρτωση απομένοντων ολοκληρωμένων εργασιών",
    "(New category)" : "(Νέα κατηγορία)",
    "Select categories..." : "Επιλογή κατηγοριών...",
    "Loading the task..." : "Φόρτωση της εργασίας...",
    "Task not found!" : "Δεν βρέθηκε εργασία!",
    "add a subtask to" : "προσθήκη υποέργου σε"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/el.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Εργασίες",
    "Due yesterday" : "Προθεσμία χθες",
    "Due today" : "Προθεσμία σήμερα",
    "Due tomorrow" : "Προθεσμία αύριο",
    "Due on" : "Προθεσμία στις",
    "Started yesterday" : "Άρχισε χθες",
    "Starts today" : "Αρχίζει σήμερα",
    "Starts tomorrow" : "Αρχίζει αύριο",
    "Started on" : "Άρχισε στις",
    "Starts on" : "Αρχίζει στις",
    "[Remind me yesterday at ]HH:mm" : "[Θύμισέ μου χθες στις ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Θύμισέ μου σήμερα στις ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Θύμισέ μου αύριο στις ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Θύμισέ μου στις ]MMM DD, YYYY,[ στις ]HH:mm",
    "Yesterday" : "Χθες",
    "Today" : "Σήμερα",
    "Tomorrow" : "Αύριο",
    "in %s" : "σε %s",
    "%s ago" : "%s πριν",
    "seconds" : "δευτερόλεπτα",
    "a minute" : "ένα λεπτό",
    "%d minutes" : "%d λεπτά",
    "an hour" : "μια ώρα",
    "%d hours" : "%d ώρες",
    "a day" : "μια ημέρα",
    "%d days" : "%d ημέρες",
    "a month" : "ένας μήνας",
    "%d months" : "%d μήνες",
    "a year" : "ένα έτος",
    "%d years" : "%d έτη",
    "week" : "εβδομάδα",
    "weeks" : "εβδομάδες",
    "day" : "ημέρα",
    "days" : "ημέρες",
    "hour" : "ώρα",
    "hours" : "ώρες",
    "minute" : "λεπτό",
    "minutes" : "λεπτά",
    "second" : "δευτερόλεπτο",
    "before beginning" : "πριν την έναρξη",
    "after beginning" : "μετά την έναρξη",
    "before end" : "πριν τη λήξη",
    "after end" : "μετά τη λήξη",
    "Comment" : "Σχόλιο",
    "Add a comment" : "Προσθήκη σχολίου",
    "This will delete the Calendar \"%s\" and all of its entries." : "Αυτό θα διαγράψει το Ημερολόγιο \"%s\" και όλες τις εγγραφές του.",
    "The name \"%s\" is already used." : "Το όνομα \"%s\" χρησιμοποιείται ήδη.",
    "An empty name is not allowed." : "Δεν επιτρέπεται κενό όνομα.",
    "Hidden" : "Κρυφό",
    "Visible" : "Ορατό",
    "Automatic" : "Αυτόματο",
    "Sunday" : "Κυριακή",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Add an important item in \"%s\"..." : "Προσθήκη ενός σημαντικού στοιχείου στο \"%s\"...",
    "Add an item due today in \"%s\"..." : "Προσθήκη ενός στοιχείου με σημερινή προθεσμία στο \"%s\"...",
    "Add an item in \"%s\"..." : "Προσθήκη ενός στοιχείου στο \"%s\"...",
    "Add a current item in \"%s\"..." : "Προσθήκη ενός τρέχοντος στοιχείου στο \"%s\"...",
    "Add a subtask to \"%s\"..." : "Προσθήκη υποέργου σε \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Ολοκληρωμένη Εργασία","%n Ολοκληρωμένες Εργασίες"],
    "Hours" : "Ώρες",
    "Minutes" : "Λεπτά",
    "Set due date" : "Ορισμός προθεσμίας",
    "%s %% completed" : "%s %% ολοκληρωμένες",
    "priority %s: " : "προτεραιότητα %s:",
    "high" : "υψηλή",
    "medium" : "μεσαία",
    "low" : "χαμηλή",
    "no priority assigned" : "δεν έχει οριστεί προτεραιότητα",
    "Remind me" : "Θύμισέ μου",
    "at the end" : "στο τέλος",
    "at the beginning" : "στην αρχή",
    "Set start date" : "Ορισμός ημερομηνίας έναρξης",
    "{calendar} shared by {owner}" : "Το {calendar} διαμοιράστηκε από τον/την {owner}",
    "Unnamed" : "Ανώνυμο",
    "Important" : "Σημαντικό ",
    "Week" : "Εβδομάδα",
    "All" : "Όλες",
    "Current" : "Τρέχουσα",
    "Completed" : "Ολοκληρωμένες",
    "Delete" : "Διαγραφή",
    "Cancel" : "Άκυρο",
    "Edit" : "Επεξεργασία",
    "Link" : "Σύνδεσμος",
    "Download" : "Λήψη",
    "Save" : "Αποθήκευση",
    "Add List..." : "Προσθήκη Λίστας...",
    "New List" : "Νέα Λίστα",
    "Settings" : "Ρυθμίσεις",
    "Start of week" : "Αρχή της εβδομάδας",
    "Visibility of Smart Collections" : "Ορατότητα Έξυπνων Συλλογών",
    "Change sort order" : "Αλλαγή σειράς ταξινόμησης",
    "Default" : "Προκαθορισμένο",
    "Due date" : "Ημερομηνία λήξης",
    "Start date" : "Ημερομηνία έναρξης",
    "Priority" : "Προτεραιότητα",
    "Alphabetically" : "Αλφαβητικά",
    "Manually" : "Χειροκίνητα",
    "Load remaining completed tasks." : "Φόρτωση απομένοντων ολοκληρωμένων εργασιών",
    "All day" : "Ολοήμερο",
    "(New category)" : "(Νέα κατηγορία)",
    "Select categories..." : "Επιλογή κατηγοριών...",
    "Loading the task..." : "Φόρτωση της εργασίας...",
    "Task not found!" : "Δεν βρέθηκε εργασία!",
    "add a subtask to" : "προσθήκη υποέργου σε"
},
"nplurals=2; plural=(n != 1);");
